require 'helper'

class TestFailure < Test::Unit::TestCase
  context "Noti" do
    setup do
      Resque::Plugins::NotiFailure::Failure.configure do |config|
        config.failure_url = 'http://test.host/resque/failure'
        config.failure_name = 'resque test'
        config.failure_message = lambda{|payload| "Resque error : #{payload['class'].to_s}"}
      end

      Resque.redis.sadd('noti-users', 'user1')
      Resque.redis.sadd('noti-users', 'user2')
    end

    should "should be notified of an error" do
      exception = StandardError.new("BOOM")
      worker = Resque::Worker.new(:test)
      queue = "test"
      payload = {'class' => Object, 'args' => 66}

      ::Noti::Notification.any_instance.expects(:title=).with('resque test')
      ::Noti::Notification.any_instance.expects(:url=).with('http://test.host/resque/failure')
      ::Noti::Notification.any_instance.expects(:text=).with('Resque error : Object')
      ::Noti::Notification.any_instance.expects(:deliver_to).twice.with(any_of('user1', 'user2'))

      backend = Resque::Plugins::NotiFailure::Failure.new(exception, worker, queue, payload)
      backend.save
    end
    
    should "not raise on count" do
      assert_nothing_raised do
        Resque::Plugins::NotiFailure::Failure.count
      end
    end
  end
end
